import 'dart:async';
import 'dart:html';
import 'package:angular/angular.dart';

@Component(
    selector: 'font-loader',
    template: '''<template [ngIf]="internalShow">
    <ng-content></ng-content>
  </template>''',
    styles: [
      ':host { opacity: 0; transition: opacity, 1s; display: block }',
      ':host.show { opacity: 1 }',
      ':host.hide { opacity: 0 }'
    ],
    directives: [coreDirectives],
    changeDetection: ChangeDetectionStrategy.OnPush)
class AnimateComponent {
  AnimateComponent(this._ref, this._cd) {
    _ref.onTransitionEnd.listen((TransitionEvent eve) {
      if (!isVisible) {
        internalShow = false;
        _invisibleCtrl.add(true);
      } else {
        _visibleCtrl.add(true);
      }

      _cd.markForCheck();
    });
  }

  final HtmlElement _ref;
  final ChangeDetectorRef _cd;

  final _invisibleCtrl = StreamController<bool>.broadcast();

  @Output()
  Stream<bool> get invisible => _invisibleCtrl.stream;

  final _visibleCtrl = StreamController<bool>.broadcast();

  @Output()
  Stream<bool> get visible => _visibleCtrl.stream;

  bool _isVisible = false;
  bool get isVisible => _isVisible;
  @Input()
  set isVisible(bool n) {
    if (n) {
      _showIt();
    } else {
      _hideIt();
    }
  }

  bool internalShow = false;

  Future<void> _showIt() async {
    _isVisible = true;
    _ref.classes
      ..add('show')
      ..remove('hide');
    internalShow = true;
    _cd.markForCheck();
  }

  Future<void> _hideIt() async {
    _isVisible = false;
    _ref.classes
      ..remove('show')
      ..add('hide');
  }
}
