import 'dart:html';
import 'package:angular/angular.dart';
import 'package:animejs/animejs.dart';
import '../models.dart';
import '../enums.dart';
import '../src/service.dart';

@Directive(
    selector: '[font-loader]'
)
class FontLoaderComponent implements AfterChanges {
  FontLoaderComponent(this._font, this._cd, this._element);

  final ChangeDetectorRef _cd;
  final FontService _font;
  final HtmlElement _element;

  @HostBinding('style.font-family')
  String? familyName;

  @HostBinding('style.font-weight')
  String? weight;

  @HostBinding('style.font-style')
  String? style;

  @Input('font-loader')
  FontStyle? loader;

  @Input('font-family')
  FontFamily? family;

  @Input()
  bool animate = false;

  Anime? _anime;

  @override
  void ngAfterChanges() {
    final loader = this.loader;

    if (loader != null) {
      final family = this.family ?? loader.family;

      assert(family?.styles?.isNotEmpty == true,
      'The font style must have a family with styles attached');

      if (family != null) {
        familyName = null;

        if (animate) {
          enableAnimeJS().then((ev) {
            if (familyName == null) {
              final opts = Options(
                  targets: _element,
                  opacity: 0,
                  loop: true
              );
              anime(opts);
            }
          });
        }

        _font.use(family).then((ev) {
          familyName = family.name;
          weight = loader.weight?.numeric.toString();
          style = loader.italic == true ? 'italic' : null;
          _cd.markForCheck();
          _anime?.pause();
        });
      }
    } else {
      weight = null;
      familyName = null;
      style = null;
    }
  }
}
