import 'dart:async';
import 'dart:html';
import '../models.dart';
import '../enums.dart';
import 'helpers.dart';
import 'interface.dart';

class FontService {
  final _loaded = <String, FutureOr<bool>>{};

  Future<bool> _check(FontFamily font) async {
    final name = font.name!;
    final styles = font.styles!;
    final fonts = document.fonts!;

    final needs = styles.any((style) {
      final hash = [
        if (style.italic == true) 'italic',
        style.weight!.numeric,
        '12px',
        name
      ].join(' ');
      final ret = !fonts.check(hash);

      return ret;
    });

    if (needs) {
      await enableWebFontLoader();

      if (font is GoogleFontFamily) {
        await loadFont(Options(
            google: GoogleFonts(families: [
              [
                name,
                styles
                    .map((style) => [
                  style.weight!.numeric,
                  if (style.italic == true) 'italic'
                ].join(''))
                    .join(',')
              ].join(':')
            ])));
      } else {
        throw 'Unknown font type to load $font';
      }
    }

    _loaded[name] = true;
    return true;
  }

  Future<void> use(FontFamily font) async {
    assert(font.name?.isNotEmpty == true,
      'The font family must have a name. $font');
    assert(font.styles?.isNotEmpty == true,
      'There must be at least one style in the font family styles. $font');

    final name = font.name!;
    final key = name;
    final loaded = _loaded[key];

    if (loaded == null) {
      final cmp = _check(font);

      _loaded[key] = cmp;

      await cmp;
    } else if (loaded != true) {
      await loaded;
    }
  }
}
